FileFormats Extension - Medimage
================================
.. image:: https://github.com/ArcanaFramework/fileformats-medimage/actions/workflows/tests.yml/badge.svg
   :target: https://github.com/ArcanaFramework/fileformats-medimage/actions/workflows/tests.yml
.. image:: https://codecov.io/gh/ArcanaFramework/fileformats-medimage/branch/main/graph/badge.svg?token=UIS0OGPST7
   :target: https://codecov.io/gh/ArcanaFramework/fileformats-medimage
.. .. image:: https://readthedocs.org/projects/arcana/badge/?version=latest
..  :target: http://arcana.readthedocs.io/en/latest/?badge=latest
..   :alt: Documentation Status

This is a template for an extension module to the
`fileformats <https://github.com/ArcanaFramework/fileformats-core>`__ package that adds
support for commonly used medical imaging formats, such as DICOM, NIfTI, and MRtrix
Image Format.


Quick Installation
------------------

This extension can be installed for Python 3 using *pip*::

    $ pip3 install fileformats-medimage

This will install the core package and any other dependencies

License
-------

This work is licensed under a
`Creative Commons Attribution 4.0 International License <http://creativecommons.org/licenses/by/4.0/>`__

.. image:: https://i.creativecommons.org/l/by/4.0/88x31.png
  :target: http://creativecommons.org/licenses/by/4.0/
  :alt: Creative Commons Attribution 4.0 International License
